#!/usr/bin/env python3
# -*- coding: utf-8 -*-

# Import support libraries.
import sys
sys.path.append('hexapod_robot') # Allow hexapod simulation API support.
import hexapod_robot.HexapodRobot as hexapod # Import hexapod simulation API.
from messages import * # Import communication messages.

# Bind to the particular hexapod, which is already loaded in the simulation.
robot = hexapod.HexapodRobot(0)

# Turn on the robot.
robot.turn_on()

# Start navigation thread.
robot.start_navigation()
time.sleep(3)

# Prepare waypoints for navigation.
waypoints = [
    Pose(Vector3(0,-3,0),Quaternion(1,0,0,0)),
    Pose(Vector3(-1.5,1.5,0),Quaternion(1,0,0,0)),
]

# Now traverse the sequence of waypoints.
for waypoint in waypoints:
    # Set the waypoint, select the controller.
    robot.goto(waypoint)
    #robot.goto_reactive(waypoint)

    # Wait until the robot reached.
    while robot.navigation_goal is not None:
        if robot.odometry_ is not None:
            odom = robot.odometry_.pose
            odom.position.z = 0
            dist = waypoint.dist(odom)
            print("\r[t1c_eval] Distance to current waypoint: %.2f" % dist, end="")
        time.sleep(0.1)

# Everything is done. Finish.
robot.stop_navigation()
robot.turn_off()

# Such a nice trajectory...
#waypoints = [
#    Pose(Vector3(0,-2,0),Quaternion(1,0,0,0)),
#    Pose(Vector3(1,.25,0),Quaternion(1,0,0,0)),
#    Pose(Vector3(0,-.1,0),Quaternion(1,0,0,0)),
#    Pose(Vector3(-.2,.1,0),Quaternion(1,0,0,0)),
#    Pose(Vector3(-.5,.5,0),Quaternion(1,0,0,0)),
#    Pose(Vector3(0,-2,0),Quaternion(1,0,0,0)),
#]

